# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/openolt.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from voltha_protos import tech_profile_pb2 as voltha__protos_dot_tech__profile__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import ext_config_pb2 as voltha__protos_dot_ext__config__pb2

from voltha_protos.tech_profile_pb2 import *
from voltha_protos.common_pb2 import *

DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/openolt.proto',
  package='openolt',
  syntax='proto3',
  serialized_options=b'\n\033org.opencord.voltha.openoltB\rVolthaOpenOLTZ/github.com/opencord/voltha-protos/v3/go/openolt',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1bvoltha_protos/openolt.proto\x12\x07openolt\x1a\x1cgoogle/api/annotations.proto\x1a voltha_protos/tech_profile.proto\x1a\x1avoltha_protos/common.proto\x1a\x1evoltha_protos/ext_config.proto\"\xe9\x03\n\nIndication\x12)\n\x07olt_ind\x18\x01 \x01(\x0b\x32\x16.openolt.OltIndicationH\x00\x12+\n\x08intf_ind\x18\x02 \x01(\x0b\x32\x17.openolt.IntfIndicationH\x00\x12\x34\n\rintf_oper_ind\x18\x03 \x01(\x0b\x32\x1b.openolt.IntfOperIndicationH\x00\x12\x32\n\x0conu_disc_ind\x18\x04 \x01(\x0b\x32\x1a.openolt.OnuDiscIndicationH\x00\x12)\n\x07onu_ind\x18\x05 \x01(\x0b\x32\x16.openolt.OnuIndicationH\x00\x12+\n\x08omci_ind\x18\x06 \x01(\x0b\x32\x17.openolt.OmciIndicationH\x00\x12,\n\x07pkt_ind\x18\x07 \x01(\x0b\x32\x19.openolt.PacketIndicationH\x00\x12-\n\nport_stats\x18\x08 \x01(\x0b\x32\x17.openolt.PortStatisticsH\x00\x12-\n\nflow_stats\x18\t \x01(\x0b\x32\x17.openolt.FlowStatisticsH\x00\x12-\n\talarm_ind\x18\n \x01(\x0b\x32\x18.openolt.AlarmIndicationH\x00\x42\x06\n\x04\x64\x61ta\"\xf5\n\n\x0f\x41larmIndication\x12)\n\x07los_ind\x18\x01 \x01(\x0b\x32\x16.openolt.LosIndicationH\x00\x12\x36\n\x0e\x64ying_gasp_ind\x18\x02 \x01(\x0b\x32\x1c.openolt.DyingGaspIndicationH\x00\x12\x34\n\ronu_alarm_ind\x18\x03 \x01(\x0b\x32\x1b.openolt.OnuAlarmIndicationH\x00\x12\x44\n\x14onu_startup_fail_ind\x18\x04 \x01(\x0b\x32$.openolt.OnuStartupFailureIndicationH\x00\x12\x45\n\x16onu_signal_degrade_ind\x18\x05 \x01(\x0b\x32#.openolt.OnuSignalDegradeIndicationH\x00\x12\x46\n\x17onu_drift_of_window_ind\x18\x06 \x01(\x0b\x32#.openolt.OnuDriftOfWindowIndicationH\x00\x12\x44\n\x11onu_loss_omci_ind\x18\x07 \x01(\x0b\x32\'.openolt.OnuLossOfOmciChannelIndicationH\x00\x12\x44\n\x14onu_signals_fail_ind\x18\x08 \x01(\x0b\x32$.openolt.OnuSignalsFailureIndicationH\x00\x12\x43\n\x0conu_tiwi_ind\x18\t \x01(\x0b\x32+.openolt.OnuTransmissionInterferenceWarningH\x00\x12J\n\x17onu_activation_fail_ind\x18\n \x01(\x0b\x32\'.openolt.OnuActivationFailureIndicationH\x00\x12I\n\x18onu_processing_error_ind\x18\x0b \x01(\x0b\x32%.openolt.OnuProcessingErrorIndicationH\x00\x12O\n\x19onu_loss_of_sync_fail_ind\x18\x0c \x01(\x0b\x32*.openolt.OnuLossOfKeySyncFailureIndicationH\x00\x12\x42\n\x15onu_itu_pon_stats_ind\x18\r \x01(\x0b\x32!.openolt.OnuItuPonStatsIndicationH\x00\x12Q\n\x1conu_deactivation_failure_ind\x18\x0e \x01(\x0b\x32).openolt.OnuDeactivationFailureIndicationH\x00\x12\x43\n\x15onu_remote_defect_ind\x18\x0f \x01(\x0b\x32\".openolt.OnuRemoteDefectIndicationH\x00\x12Y\n\x1conu_loss_gem_delineation_ind\x18\x10 \x01(\x0b\x32\x31.openolt.OnuLossOfGEMChannelDelineationIndicationH\x00\x12X\n onu_physical_equipment_error_ind\x18\x11 \x01(\x0b\x32,.openolt.OnuPhysicalEquipmentErrorIndicationH\x00\x12J\n\x13onu_loss_of_ack_ind\x18\x12 \x01(\x0b\x32+.openolt.OnuLossOfAcknowledgementIndicationH\x00\x12V\n\x1bonu_diff_reach_exceeded_ind\x18\x13 \x01(\x0b\x32/.openolt.OnuDifferentialReachExceededIndicationH\x00\x42\x06\n\x04\x64\x61ta\"#\n\rOltIndication\x12\x12\n\noper_state\x18\x01 \x01(\t\"5\n\x0eIntfIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x12\n\noper_state\x18\x02 \x01(\t\"R\n\x11OnuDiscIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12,\n\rserial_number\x18\x02 \x01(\x0b\x32\x15.openolt.SerialNumber\"\xd3\x03\n\rOnuIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x12\n\noper_state\x18\x03 \x01(\t\x12\x13\n\x0b\x61\x64min_state\x18\x05 \x01(\t\x12,\n\rserial_number\x18\x04 \x01(\x0b\x32\x15.openolt.SerialNumber\x12@\n\x0b\x66\x61il_reason\x18\x06 \x01(\x0e\x32+.openolt.OnuIndication.ActivationFailReason\"\x87\x02\n\x14\x41\x63tivationFailReason\x12#\n\x1fONU_ACTIVATION_FAIL_REASON_NONE\x10\x00\x12&\n\"ONU_ACTIVATION_FAIL_REASON_RANGING\x10\x01\x12\x36\n2ONU_ACTIVATION_FAIL_REASON_PASSWORD_AUTHENTICATION\x10\x02\x12\"\n\x1eONU_ACTIVATION_FAIL_REASON_LOS\x10\x03\x12!\n\x1dONU_ACTIVATION_FAIL_ONU_ALARM\x10\x04\x12#\n\x1fONU_ACTIVATION_FAIL_SWITCH_OVER\x10\x05\"G\n\x12IntfOperIndication\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07intf_id\x18\x02 \x01(\x07\x12\x12\n\noper_state\x18\x03 \x01(\t\">\n\x0eOmciIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0b\n\x03pkt\x18\x03 \x01(\x0c\"\x89\x01\n\x10PacketIndication\x12\x11\n\tintf_type\x18\x05 \x01(\t\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x12\n\ngemport_id\x18\x02 \x01(\x07\x12\x0f\n\x07\x66low_id\x18\x03 \x01(\x07\x12\x0f\n\x07port_no\x18\x06 \x01(\x07\x12\x0e\n\x06\x63ookie\x18\x07 \x01(\x06\x12\x0b\n\x03pkt\x18\x04 \x01(\x0c\"\x1c\n\tInterface\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\"(\n\tHeartbeat\x12\x1b\n\x13heartbeat_signature\x18\x01 \x01(\x07\"z\n\x03Onu\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12,\n\rserial_number\x18\x03 \x01(\x0b\x32\x15.openolt.SerialNumber\x12\x0b\n\x03pir\x18\x04 \x01(\x07\x12\x17\n\x0fomcc_encryption\x18\x05 \x01(\x08\"v\n\x12OnuLogicalDistance\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12!\n\x19logical_onu_distance_zero\x18\x03 \x01(\x07\x12\x1c\n\x14logical_onu_distance\x18\x04 \x01(\x07\"7\n\x07OmciMsg\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0b\n\x03pkt\x18\x03 \x01(\x0c\"^\n\tOnuPacket\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0f\n\x07port_no\x18\x04 \x01(\x07\x12\x12\n\ngemport_id\x18\x05 \x01(\x07\x12\x0b\n\x03pkt\x18\x03 \x01(\x0c\",\n\x0cUplinkPacket\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0b\n\x03pkt\x18\x02 \x01(\x0c\"\x88\x07\n\nDeviceInfo\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\r\n\x05model\x18\x02 \x01(\t\x12\x18\n\x10hardware_version\x18\x03 \x01(\t\x12\x18\n\x10\x66irmware_version\x18\x04 \x01(\t\x12\x11\n\tdevice_id\x18\x10 \x01(\t\x12\x1c\n\x14\x64\x65vice_serial_number\x18\x11 \x01(\t\x12\x11\n\tpon_ports\x18\x0c \x01(\x07\x12\x12\n\ntechnology\x18\x05 \x01(\t\x12\x14\n\x0conu_id_start\x18\x06 \x01(\x07\x12\x12\n\nonu_id_end\x18\x07 \x01(\x07\x12\x16\n\x0e\x61lloc_id_start\x18\x08 \x01(\x07\x12\x14\n\x0c\x61lloc_id_end\x18\t \x01(\x07\x12\x18\n\x10gemport_id_start\x18\n \x01(\x07\x12\x16\n\x0egemport_id_end\x18\x0b \x01(\x07\x12\x15\n\rflow_id_start\x18\r \x01(\x07\x12\x13\n\x0b\x66low_id_end\x18\x0e \x01(\x07\x12\x38\n\x06ranges\x18\x0f \x03(\x0b\x32(.openolt.DeviceInfo.DeviceResourceRanges\x1a\xde\x03\n\x14\x44\x65viceResourceRanges\x12\x10\n\x08intf_ids\x18\x01 \x03(\x07\x12\x12\n\ntechnology\x18\x02 \x01(\t\x12<\n\x05pools\x18\x03 \x03(\x0b\x32-.openolt.DeviceInfo.DeviceResourceRanges.Pool\x1a\xe1\x02\n\x04Pool\x12\x44\n\x04type\x18\x01 \x01(\x0e\x32\x36.openolt.DeviceInfo.DeviceResourceRanges.Pool.PoolType\x12J\n\x07sharing\x18\x02 \x01(\x0e\x32\x39.openolt.DeviceInfo.DeviceResourceRanges.Pool.SharingType\x12\r\n\x05start\x18\x03 \x01(\x07\x12\x0b\n\x03\x65nd\x18\x04 \x01(\x07\"A\n\x08PoolType\x12\n\n\x06ONU_ID\x10\x00\x12\x0c\n\x08\x41LLOC_ID\x10\x01\x12\x0e\n\nGEMPORT_ID\x10\x02\x12\x0b\n\x07\x46LOW_ID\x10\x03\"h\n\x0bSharingType\x12\x16\n\x12\x44\x45\x44ICATED_PER_INTF\x10\x00\x12\x1f\n\x1bSHARED_BY_ALL_INTF_ALL_TECH\x10\x01\x12 \n\x1cSHARED_BY_ALL_INTF_SAME_TECH\x10\x02\"\x8c\x02\n\nClassifier\x12\x0e\n\x06o_tpid\x18\x01 \x01(\x07\x12\r\n\x05o_vid\x18\x02 \x01(\x07\x12\x0e\n\x06i_tpid\x18\x03 \x01(\x07\x12\r\n\x05i_vid\x18\x04 \x01(\x07\x12\x0f\n\x07o_pbits\x18\x05 \x01(\x07\x12\x0f\n\x07i_pbits\x18\x06 \x01(\x07\x12\x10\n\x08\x65th_type\x18\x07 \x01(\x07\x12\x0f\n\x07\x64st_mac\x18\x08 \x01(\x0c\x12\x0f\n\x07src_mac\x18\t \x01(\x0c\x12\x10\n\x08ip_proto\x18\n \x01(\x07\x12\x0e\n\x06\x64st_ip\x18\x0b \x01(\x07\x12\x0e\n\x06src_ip\x18\x0c \x01(\x07\x12\x10\n\x08src_port\x18\r \x01(\x07\x12\x10\n\x08\x64st_port\x18\x0e \x01(\x07\x12\x14\n\x0cpkt_tag_type\x18\x0f \x01(\t\"\xf5\x01\n\tActionCmd\x12\x15\n\radd_outer_tag\x18\x01 \x01(\x08\x12\x18\n\x10remove_outer_tag\x18\x02 \x01(\x08\x12\x14\n\x0ctrap_to_host\x18\x03 \x01(\x08\x12\x1a\n\x12remark_outer_pbits\x18\x04 \x01(\x08\x12\x1a\n\x12remark_inner_pbits\x18\x05 \x01(\x08\x12\x15\n\radd_inner_tag\x18\x06 \x01(\x08\x12\x18\n\x10remove_inner_tag\x18\x07 \x01(\x08\x12\x1b\n\x13translate_inner_tag\x18\x08 \x01(\x08\x12\x1b\n\x13translate_outer_tag\x18\t \x01(\x08\"\x89\x01\n\x06\x41\x63tion\x12\x1f\n\x03\x63md\x18\x01 \x01(\x0b\x32\x12.openolt.ActionCmd\x12\r\n\x05o_vid\x18\x02 \x01(\x07\x12\x0f\n\x07o_pbits\x18\x03 \x01(\x07\x12\x0e\n\x06o_tpid\x18\x04 \x01(\x07\x12\r\n\x05i_vid\x18\x05 \x01(\x07\x12\x0f\n\x07i_pbits\x18\x06 \x01(\x07\x12\x0e\n\x06i_tpid\x18\x07 \x01(\x07\"\xed\x03\n\x04\x46low\x12\x16\n\x0e\x61\x63\x63\x65ss_intf_id\x18\x01 \x01(\x0f\x12\x0e\n\x06onu_id\x18\x02 \x01(\x0f\x12\x0e\n\x06uni_id\x18\x0b \x01(\x0f\x12\x0f\n\x07\x66low_id\x18\x03 \x01(\x06\x12\x19\n\x11symmetric_flow_id\x18\x12 \x01(\x06\x12\x11\n\tflow_type\x18\x04 \x01(\t\x12\x10\n\x08\x61lloc_id\x18\n \x01(\x0f\x12\x17\n\x0fnetwork_intf_id\x18\x05 \x01(\x0f\x12\x12\n\ngemport_id\x18\x06 \x01(\x0f\x12\'\n\nclassifier\x18\x07 \x01(\x0b\x32\x13.openolt.Classifier\x12\x1f\n\x06\x61\x63tion\x18\x08 \x01(\x0b\x32\x0f.openolt.Action\x12\x10\n\x08priority\x18\t \x01(\x0f\x12\x0e\n\x06\x63ookie\x18\x0c \x01(\x06\x12\x0f\n\x07port_no\x18\r \x01(\x07\x12\x10\n\x08group_id\x18\x0e \x01(\x07\x12\x17\n\x0ftech_profile_id\x18\x0f \x01(\x07\x12\x16\n\x0ereplicate_flow\x18\x10 \x01(\x08\x12\x39\n\x0fpbit_to_gemport\x18\x11 \x03(\x0b\x32 .openolt.Flow.PbitToGemportEntry\x1a\x34\n\x12PbitToGemportEntry\x12\x0b\n\x03key\x18\x01 \x01(\x07\x12\r\n\x05value\x18\x02 \x01(\x07:\x02\x38\x01\":\n\x0cSerialNumber\x12\x11\n\tvendor_id\x18\x01 \x01(\x0c\x12\x17\n\x0fvendor_specific\x18\x02 \x01(\x0c\"\xfb\x02\n\x0ePortStatistics\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x10\n\x08rx_bytes\x18\x02 \x01(\x06\x12\x12\n\nrx_packets\x18\x03 \x01(\x06\x12\x18\n\x10rx_ucast_packets\x18\x04 \x01(\x06\x12\x18\n\x10rx_mcast_packets\x18\x05 \x01(\x06\x12\x18\n\x10rx_bcast_packets\x18\x06 \x01(\x06\x12\x18\n\x10rx_error_packets\x18\x07 \x01(\x06\x12\x10\n\x08tx_bytes\x18\x08 \x01(\x06\x12\x12\n\ntx_packets\x18\t \x01(\x06\x12\x18\n\x10tx_ucast_packets\x18\n \x01(\x06\x12\x18\n\x10tx_mcast_packets\x18\x0b \x01(\x06\x12\x18\n\x10tx_bcast_packets\x18\x0c \x01(\x06\x12\x18\n\x10tx_error_packets\x18\r \x01(\x06\x12\x15\n\rrx_crc_errors\x18\x0e \x01(\x06\x12\x12\n\nbip_errors\x18\x0f \x01(\x06\x12\x11\n\ttimestamp\x18\x10 \x01(\x07\"\x80\x01\n\x0e\x46lowStatistics\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\x07\x12\x10\n\x08rx_bytes\x18\x02 \x01(\x06\x12\x12\n\nrx_packets\x18\x03 \x01(\x06\x12\x10\n\x08tx_bytes\x18\x08 \x01(\x06\x12\x12\n\ntx_packets\x18\t \x01(\x06\x12\x11\n\ttimestamp\x18\x10 \x01(\x07\"0\n\rLosIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06status\x18\x02 \x01(\t\"F\n\x13\x44yingGaspIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\"\xc1\x01\n\x12OnuAlarmIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x12\n\nlos_status\x18\x03 \x01(\t\x12\x12\n\nlob_status\x18\x04 \x01(\t\x12\x18\n\x10lopc_miss_status\x18\x05 \x01(\t\x12\x1d\n\x15lopc_mic_error_status\x18\x06 \x01(\t\x12\x13\n\x0blofi_status\x18\x07 \x01(\t\x12\x14\n\x0cloami_status\x18\x08 \x01(\t\"N\n\x1bOnuStartupFailureIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\"m\n\x1aOnuSignalDegradeIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x1e\n\x16inverse_bit_error_rate\x18\x04 \x01(\x07\"m\n\x1aOnuDriftOfWindowIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05\x64rift\x18\x04 \x01(\x07\x12\x0f\n\x07new_eqd\x18\x05 \x01(\x07\"Q\n\x1eOnuLossOfOmciChannelIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\"n\n\x1bOnuSignalsFailureIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x1e\n\x16inverse_bit_error_rate\x18\x04 \x01(\x07\"d\n\"OnuTransmissionInterferenceWarning\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05\x64rift\x18\x04 \x01(\x07\"V\n\x1eOnuActivationFailureIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x13\n\x0b\x66\x61il_reason\x18\x03 \x01(\x07\"T\n!OnuLossOfKeySyncFailureIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\"=\n\x12RdiErrorIndication\x12\x17\n\x0frdi_error_count\x18\x01 \x01(\x06\x12\x0e\n\x06status\x18\x02 \x01(\t\"z\n\x18OnuItuPonStatsIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x34\n\rrdi_error_ind\x18\x03 \x01(\x0b\x32\x1b.openolt.RdiErrorIndicationH\x00\x42\x07\n\x05stats\"?\n\x1cOnuProcessingErrorIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\"S\n OnuDeactivationFailureIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\"P\n\x19OnuRemoteDefectIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x12\n\nrdi_errors\x18\x03 \x01(\x06\"w\n(OnuLossOfGEMChannelDelineationIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x1a\n\x12\x64\x65lineation_errors\x18\x04 \x01(\x07\"V\n#OnuPhysicalEquipmentErrorIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\"U\n\"OnuLossOfAcknowledgementIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\"k\n&OnuDifferentialReachExceededIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x10\n\x08\x64istance\x18\x04 \x01(\x07\"\xc5\x01\n\x0bGroupMember\x12\x14\n\x0cinterface_id\x18\x01 \x01(\r\x12:\n\x0einterface_type\x18\x02 \x01(\x0e\x32\".openolt.GroupMember.InterfaceType\x12\x13\n\x0bgem_port_id\x18\x03 \x01(\r\x12\x10\n\x08priority\x18\x04 \x01(\r\"=\n\rInterfaceType\x12\x07\n\x03PON\x10\x00\x12\x10\n\x0c\x45PON_1G_PATH\x10\x01\x12\x11\n\rEPON_10G_PATH\x10\x02\"\xe3\x01\n\x05Group\x12\x10\n\x08group_id\x18\x01 \x01(\r\x12\x33\n\x07\x63ommand\x18\x02 \x01(\x0e\x32\".openolt.Group.GroupMembersCommand\x12%\n\x07members\x18\x03 \x03(\x0b\x32\x14.openolt.GroupMember\x12\x1f\n\x06\x61\x63tion\x18\x04 \x01(\x0b\x32\x0f.openolt.Action\"K\n\x13GroupMembersCommand\x12\x0f\n\x0b\x41\x44\x44_MEMBERS\x10\x00\x12\x12\n\x0eREMOVE_MEMBERS\x10\x01\x12\x0f\n\x0bSET_MEMBERS\x10\x02\"N\n\nValueParam\x12\x19\n\x03onu\x18\x01 \x01(\x0b\x32\x0c.openolt.Onu\x12%\n\x05value\x18\x02 \x01(\x0e\x32\x16.common.ValueType.Type\"\x07\n\x05\x45mpty2\xfe\x11\n\x07Openolt\x12\x44\n\nDisableOlt\x12\x0e.openolt.Empty\x1a\x0e.openolt.Empty\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/Disable:\x01*\x12\x46\n\x0bReenableOlt\x12\x0e.openolt.Empty\x1a\x0e.openolt.Empty\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/Reenable:\x01*\x12\x45\n\x0b\x41\x63tivateOnu\x12\x0c.openolt.Onu\x1a\x0e.openolt.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\"\r/v1/EnableOnu:\x01*\x12H\n\rDeactivateOnu\x12\x0c.openolt.Onu\x1a\x0e.openolt.Empty\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/DisableOnu:\x01*\x12\x43\n\tDeleteOnu\x12\x0c.openolt.Onu\x1a\x0e.openolt.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\"\r/v1/DeleteOnu:\x01*\x12I\n\nOmciMsgOut\x12\x10.openolt.OmciMsg\x1a\x0e.openolt.Empty\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/OmciMsgOut:\x01*\x12O\n\x0cOnuPacketOut\x12\x12.openolt.OnuPacket\x1a\x0e.openolt.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v1/OnuPacketOut:\x01*\x12X\n\x0fUplinkPacketOut\x12\x15.openolt.UplinkPacket\x1a\x0e.openolt.Empty\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v1/UplinkPacketOut:\x01*\x12@\n\x07\x46lowAdd\x12\r.openolt.Flow\x1a\x0e.openolt.Empty\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/FlowAdd:\x01*\x12\x46\n\nFlowRemove\x12\r.openolt.Flow\x1a\x0e.openolt.Empty\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/FlowRemove:\x01*\x12S\n\x0eHeartbeatCheck\x12\x0e.openolt.Empty\x1a\x12.openolt.Heartbeat\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/HeartbeatCheck:\x01*\x12M\n\x0b\x45nablePonIf\x12\x12.openolt.Interface\x1a\x0e.openolt.Empty\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/EnablePonIf:\x01*\x12O\n\x0c\x44isablePonIf\x12\x12.openolt.Interface\x1a\x0e.openolt.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v1/DisablePonIf:\x01*\x12R\n\rGetDeviceInfo\x12\x0e.openolt.Empty\x1a\x13.openolt.DeviceInfo\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/GetDeviceInfo:\x01*\x12?\n\x06Reboot\x12\x0e.openolt.Empty\x1a\x0e.openolt.Empty\"\x15\x82\xd3\xe4\x93\x02\x0f\"\n/v1/Reboot:\x01*\x12U\n\x11\x43ollectStatistics\x12\x0e.openolt.Empty\x1a\x0e.openolt.Empty\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v1/CollectStatistics:\x01*\x12r\n\x17\x43reateTrafficSchedulers\x12\x1f.tech_profile.TrafficSchedulers\x1a\x0e.openolt.Empty\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/CreateTrafficSchedulers:\x01*\x12r\n\x17RemoveTrafficSchedulers\x12\x1f.tech_profile.TrafficSchedulers\x1a\x0e.openolt.Empty\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/RemoveTrafficSchedulers:\x01*\x12\x66\n\x13\x43reateTrafficQueues\x12\x1b.tech_profile.TrafficQueues\x1a\x0e.openolt.Empty\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/v1/CreateTrafficQueues:\x01*\x12\x66\n\x13RemoveTrafficQueues\x12\x1b.tech_profile.TrafficQueues\x1a\x0e.openolt.Empty\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/v1/RemoveTrafficQueues:\x01*\x12;\n\x10\x45nableIndication\x12\x0e.openolt.Empty\x1a\x13.openolt.Indication\"\x00\x30\x01\x12]\n\x15PerformGroupOperation\x12\x0e.openolt.Group\x1a\x0e.openolt.Empty\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v1/PerformGroupOperation:\x01*\x12I\n\x0b\x44\x65leteGroup\x12\x0e.openolt.Group\x1a\x0e.openolt.Empty\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/DeleteGroup:\x01*\x12T\n\x0bGetExtValue\x12\x13.openolt.ValueParam\x1a\x14.common.ReturnValues\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/GetExtValue:\x01*\x12]\n\x11OnuItuPonAlarmSet\x12\x16.config.OnuItuPonAlarm\x1a\x0e.openolt.Empty\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v1/OnuItuPonAlarmSet:\x01*\x12p\n\x19GetLogicalOnuDistanceZero\x12\x0c.openolt.Onu\x1a\x1b.openolt.OnuLogicalDistance\"(\x82\xd3\xe4\x93\x02\"\"\x1d/v1/GetLogicalOnuDistanceZero:\x01*\x12h\n\x15GetLogicalOnuDistance\x12\x0c.openolt.Onu\x1a\x1b.openolt.OnuLogicalDistance\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v1/GetLogicalOnuDistance:\x01*B]\n\x1borg.opencord.voltha.openoltB\rVolthaOpenOLTZ/github.com/opencord/voltha-protos/v3/go/openoltP\x01P\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,voltha__protos_dot_tech__profile__pb2.DESCRIPTOR,voltha__protos_dot_common__pb2.DESCRIPTOR,voltha__protos_dot_ext__config__pb2.DESCRIPTOR,],
  public_dependencies=[voltha__protos_dot_tech__profile__pb2.DESCRIPTOR,voltha__protos_dot_common__pb2.DESCRIPTOR,])



_ONUINDICATION_ACTIVATIONFAILREASON = _descriptor.EnumDescriptor(
  name='ActivationFailReason',
  full_name='openolt.OnuIndication.ActivationFailReason',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ONU_ACTIVATION_FAIL_REASON_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONU_ACTIVATION_FAIL_REASON_RANGING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONU_ACTIVATION_FAIL_REASON_PASSWORD_AUTHENTICATION', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONU_ACTIVATION_FAIL_REASON_LOS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONU_ACTIVATION_FAIL_ONU_ALARM', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONU_ACTIVATION_FAIL_SWITCH_OVER', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2437,
  serialized_end=2700,
)
_sym_db.RegisterEnumDescriptor(_ONUINDICATION_ACTIVATIONFAILREASON)

_DEVICEINFO_DEVICERESOURCERANGES_POOL_POOLTYPE = _descriptor.EnumDescriptor(
  name='PoolType',
  full_name='openolt.DeviceInfo.DeviceResourceRanges.Pool.PoolType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ONU_ID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALLOC_ID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEMPORT_ID', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLOW_ID', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4228,
  serialized_end=4293,
)
_sym_db.RegisterEnumDescriptor(_DEVICEINFO_DEVICERESOURCERANGES_POOL_POOLTYPE)

_DEVICEINFO_DEVICERESOURCERANGES_POOL_SHARINGTYPE = _descriptor.EnumDescriptor(
  name='SharingType',
  full_name='openolt.DeviceInfo.DeviceResourceRanges.Pool.SharingType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEDICATED_PER_INTF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHARED_BY_ALL_INTF_ALL_TECH', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHARED_BY_ALL_INTF_SAME_TECH', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4295,
  serialized_end=4399,
)
_sym_db.RegisterEnumDescriptor(_DEVICEINFO_DEVICERESOURCERANGES_POOL_SHARINGTYPE)

_GROUPMEMBER_INTERFACETYPE = _descriptor.EnumDescriptor(
  name='InterfaceType',
  full_name='openolt.GroupMember.InterfaceType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PON', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPON_1G_PATH', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPON_10G_PATH', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8181,
  serialized_end=8242,
)
_sym_db.RegisterEnumDescriptor(_GROUPMEMBER_INTERFACETYPE)

_GROUP_GROUPMEMBERSCOMMAND = _descriptor.EnumDescriptor(
  name='GroupMembersCommand',
  full_name='openolt.Group.GroupMembersCommand',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADD_MEMBERS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REMOVE_MEMBERS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SET_MEMBERS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8397,
  serialized_end=8472,
)
_sym_db.RegisterEnumDescriptor(_GROUP_GROUPMEMBERSCOMMAND)


_INDICATION = _descriptor.Descriptor(
  name='Indication',
  full_name='openolt.Indication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='olt_ind', full_name='openolt.Indication.olt_ind', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intf_ind', full_name='openolt.Indication.intf_ind', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intf_oper_ind', full_name='openolt.Indication.intf_oper_ind', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_disc_ind', full_name='openolt.Indication.onu_disc_ind', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_ind', full_name='openolt.Indication.onu_ind', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='omci_ind', full_name='openolt.Indication.omci_ind', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pkt_ind', full_name='openolt.Indication.pkt_ind', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_stats', full_name='openolt.Indication.port_stats', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flow_stats', full_name='openolt.Indication.flow_stats', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alarm_ind', full_name='openolt.Indication.alarm_ind', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='openolt.Indication.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=165,
  serialized_end=654,
)


_ALARMINDICATION = _descriptor.Descriptor(
  name='AlarmIndication',
  full_name='openolt.AlarmIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='los_ind', full_name='openolt.AlarmIndication.los_ind', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dying_gasp_ind', full_name='openolt.AlarmIndication.dying_gasp_ind', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_alarm_ind', full_name='openolt.AlarmIndication.onu_alarm_ind', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_startup_fail_ind', full_name='openolt.AlarmIndication.onu_startup_fail_ind', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_signal_degrade_ind', full_name='openolt.AlarmIndication.onu_signal_degrade_ind', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_drift_of_window_ind', full_name='openolt.AlarmIndication.onu_drift_of_window_ind', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_loss_omci_ind', full_name='openolt.AlarmIndication.onu_loss_omci_ind', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_signals_fail_ind', full_name='openolt.AlarmIndication.onu_signals_fail_ind', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_tiwi_ind', full_name='openolt.AlarmIndication.onu_tiwi_ind', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_activation_fail_ind', full_name='openolt.AlarmIndication.onu_activation_fail_ind', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_processing_error_ind', full_name='openolt.AlarmIndication.onu_processing_error_ind', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_loss_of_sync_fail_ind', full_name='openolt.AlarmIndication.onu_loss_of_sync_fail_ind', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_itu_pon_stats_ind', full_name='openolt.AlarmIndication.onu_itu_pon_stats_ind', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_deactivation_failure_ind', full_name='openolt.AlarmIndication.onu_deactivation_failure_ind', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_remote_defect_ind', full_name='openolt.AlarmIndication.onu_remote_defect_ind', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_loss_gem_delineation_ind', full_name='openolt.AlarmIndication.onu_loss_gem_delineation_ind', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_physical_equipment_error_ind', full_name='openolt.AlarmIndication.onu_physical_equipment_error_ind', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_loss_of_ack_ind', full_name='openolt.AlarmIndication.onu_loss_of_ack_ind', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_diff_reach_exceeded_ind', full_name='openolt.AlarmIndication.onu_diff_reach_exceeded_ind', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='openolt.AlarmIndication.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=657,
  serialized_end=2054,
)


_OLTINDICATION = _descriptor.Descriptor(
  name='OltIndication',
  full_name='openolt.OltIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oper_state', full_name='openolt.OltIndication.oper_state', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2056,
  serialized_end=2091,
)


_INTFINDICATION = _descriptor.Descriptor(
  name='IntfIndication',
  full_name='openolt.IntfIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.IntfIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oper_state', full_name='openolt.IntfIndication.oper_state', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2093,
  serialized_end=2146,
)


_ONUDISCINDICATION = _descriptor.Descriptor(
  name='OnuDiscIndication',
  full_name='openolt.OnuDiscIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuDiscIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='openolt.OnuDiscIndication.serial_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2148,
  serialized_end=2230,
)


_ONUINDICATION = _descriptor.Descriptor(
  name='OnuIndication',
  full_name='openolt.OnuIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oper_state', full_name='openolt.OnuIndication.oper_state', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='admin_state', full_name='openolt.OnuIndication.admin_state', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='openolt.OnuIndication.serial_number', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fail_reason', full_name='openolt.OnuIndication.fail_reason', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ONUINDICATION_ACTIVATIONFAILREASON,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2233,
  serialized_end=2700,
)


_INTFOPERINDICATION = _descriptor.Descriptor(
  name='IntfOperIndication',
  full_name='openolt.IntfOperIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='openolt.IntfOperIndication.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.IntfOperIndication.intf_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oper_state', full_name='openolt.IntfOperIndication.oper_state', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2702,
  serialized_end=2773,
)


_OMCIINDICATION = _descriptor.Descriptor(
  name='OmciIndication',
  full_name='openolt.OmciIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OmciIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OmciIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pkt', full_name='openolt.OmciIndication.pkt', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2775,
  serialized_end=2837,
)


_PACKETINDICATION = _descriptor.Descriptor(
  name='PacketIndication',
  full_name='openolt.PacketIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_type', full_name='openolt.PacketIndication.intf_type', index=0,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.PacketIndication.intf_id', index=1,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gemport_id', full_name='openolt.PacketIndication.gemport_id', index=2,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flow_id', full_name='openolt.PacketIndication.flow_id', index=3,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_no', full_name='openolt.PacketIndication.port_no', index=4,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cookie', full_name='openolt.PacketIndication.cookie', index=5,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pkt', full_name='openolt.PacketIndication.pkt', index=6,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2840,
  serialized_end=2977,
)


_INTERFACE = _descriptor.Descriptor(
  name='Interface',
  full_name='openolt.Interface',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.Interface.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2979,
  serialized_end=3007,
)


_HEARTBEAT = _descriptor.Descriptor(
  name='Heartbeat',
  full_name='openolt.Heartbeat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='heartbeat_signature', full_name='openolt.Heartbeat.heartbeat_signature', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3009,
  serialized_end=3049,
)


_ONU = _descriptor.Descriptor(
  name='Onu',
  full_name='openolt.Onu',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.Onu.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.Onu.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='openolt.Onu.serial_number', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pir', full_name='openolt.Onu.pir', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='omcc_encryption', full_name='openolt.Onu.omcc_encryption', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3051,
  serialized_end=3173,
)


_ONULOGICALDISTANCE = _descriptor.Descriptor(
  name='OnuLogicalDistance',
  full_name='openolt.OnuLogicalDistance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuLogicalDistance.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuLogicalDistance.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logical_onu_distance_zero', full_name='openolt.OnuLogicalDistance.logical_onu_distance_zero', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logical_onu_distance', full_name='openolt.OnuLogicalDistance.logical_onu_distance', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3175,
  serialized_end=3293,
)


_OMCIMSG = _descriptor.Descriptor(
  name='OmciMsg',
  full_name='openolt.OmciMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OmciMsg.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OmciMsg.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pkt', full_name='openolt.OmciMsg.pkt', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3295,
  serialized_end=3350,
)


_ONUPACKET = _descriptor.Descriptor(
  name='OnuPacket',
  full_name='openolt.OnuPacket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuPacket.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuPacket.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_no', full_name='openolt.OnuPacket.port_no', index=2,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gemport_id', full_name='openolt.OnuPacket.gemport_id', index=3,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pkt', full_name='openolt.OnuPacket.pkt', index=4,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3352,
  serialized_end=3446,
)


_UPLINKPACKET = _descriptor.Descriptor(
  name='UplinkPacket',
  full_name='openolt.UplinkPacket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.UplinkPacket.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pkt', full_name='openolt.UplinkPacket.pkt', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3448,
  serialized_end=3492,
)


_DEVICEINFO_DEVICERESOURCERANGES_POOL = _descriptor.Descriptor(
  name='Pool',
  full_name='openolt.DeviceInfo.DeviceResourceRanges.Pool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='openolt.DeviceInfo.DeviceResourceRanges.Pool.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sharing', full_name='openolt.DeviceInfo.DeviceResourceRanges.Pool.sharing', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='openolt.DeviceInfo.DeviceResourceRanges.Pool.start', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='openolt.DeviceInfo.DeviceResourceRanges.Pool.end', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DEVICEINFO_DEVICERESOURCERANGES_POOL_POOLTYPE,
    _DEVICEINFO_DEVICERESOURCERANGES_POOL_SHARINGTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4046,
  serialized_end=4399,
)

_DEVICEINFO_DEVICERESOURCERANGES = _descriptor.Descriptor(
  name='DeviceResourceRanges',
  full_name='openolt.DeviceInfo.DeviceResourceRanges',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_ids', full_name='openolt.DeviceInfo.DeviceResourceRanges.intf_ids', index=0,
      number=1, type=7, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='technology', full_name='openolt.DeviceInfo.DeviceResourceRanges.technology', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pools', full_name='openolt.DeviceInfo.DeviceResourceRanges.pools', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DEVICEINFO_DEVICERESOURCERANGES_POOL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3921,
  serialized_end=4399,
)

_DEVICEINFO = _descriptor.Descriptor(
  name='DeviceInfo',
  full_name='openolt.DeviceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='openolt.DeviceInfo.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model', full_name='openolt.DeviceInfo.model', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hardware_version', full_name='openolt.DeviceInfo.hardware_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='firmware_version', full_name='openolt.DeviceInfo.firmware_version', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_id', full_name='openolt.DeviceInfo.device_id', index=4,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_serial_number', full_name='openolt.DeviceInfo.device_serial_number', index=5,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pon_ports', full_name='openolt.DeviceInfo.pon_ports', index=6,
      number=12, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='technology', full_name='openolt.DeviceInfo.technology', index=7,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id_start', full_name='openolt.DeviceInfo.onu_id_start', index=8,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id_end', full_name='openolt.DeviceInfo.onu_id_end', index=9,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alloc_id_start', full_name='openolt.DeviceInfo.alloc_id_start', index=10,
      number=8, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alloc_id_end', full_name='openolt.DeviceInfo.alloc_id_end', index=11,
      number=9, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gemport_id_start', full_name='openolt.DeviceInfo.gemport_id_start', index=12,
      number=10, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gemport_id_end', full_name='openolt.DeviceInfo.gemport_id_end', index=13,
      number=11, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flow_id_start', full_name='openolt.DeviceInfo.flow_id_start', index=14,
      number=13, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flow_id_end', full_name='openolt.DeviceInfo.flow_id_end', index=15,
      number=14, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ranges', full_name='openolt.DeviceInfo.ranges', index=16,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DEVICEINFO_DEVICERESOURCERANGES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3495,
  serialized_end=4399,
)


_CLASSIFIER = _descriptor.Descriptor(
  name='Classifier',
  full_name='openolt.Classifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='o_tpid', full_name='openolt.Classifier.o_tpid', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='o_vid', full_name='openolt.Classifier.o_vid', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='i_tpid', full_name='openolt.Classifier.i_tpid', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='i_vid', full_name='openolt.Classifier.i_vid', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='o_pbits', full_name='openolt.Classifier.o_pbits', index=4,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='i_pbits', full_name='openolt.Classifier.i_pbits', index=5,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eth_type', full_name='openolt.Classifier.eth_type', index=6,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dst_mac', full_name='openolt.Classifier.dst_mac', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='src_mac', full_name='openolt.Classifier.src_mac', index=8,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_proto', full_name='openolt.Classifier.ip_proto', index=9,
      number=10, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dst_ip', full_name='openolt.Classifier.dst_ip', index=10,
      number=11, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='src_ip', full_name='openolt.Classifier.src_ip', index=11,
      number=12, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='src_port', full_name='openolt.Classifier.src_port', index=12,
      number=13, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dst_port', full_name='openolt.Classifier.dst_port', index=13,
      number=14, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pkt_tag_type', full_name='openolt.Classifier.pkt_tag_type', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4402,
  serialized_end=4670,
)


_ACTIONCMD = _descriptor.Descriptor(
  name='ActionCmd',
  full_name='openolt.ActionCmd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='add_outer_tag', full_name='openolt.ActionCmd.add_outer_tag', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remove_outer_tag', full_name='openolt.ActionCmd.remove_outer_tag', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trap_to_host', full_name='openolt.ActionCmd.trap_to_host', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remark_outer_pbits', full_name='openolt.ActionCmd.remark_outer_pbits', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remark_inner_pbits', full_name='openolt.ActionCmd.remark_inner_pbits', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_inner_tag', full_name='openolt.ActionCmd.add_inner_tag', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remove_inner_tag', full_name='openolt.ActionCmd.remove_inner_tag', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='translate_inner_tag', full_name='openolt.ActionCmd.translate_inner_tag', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='translate_outer_tag', full_name='openolt.ActionCmd.translate_outer_tag', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4673,
  serialized_end=4918,
)


_ACTION = _descriptor.Descriptor(
  name='Action',
  full_name='openolt.Action',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cmd', full_name='openolt.Action.cmd', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='o_vid', full_name='openolt.Action.o_vid', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='o_pbits', full_name='openolt.Action.o_pbits', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='o_tpid', full_name='openolt.Action.o_tpid', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='i_vid', full_name='openolt.Action.i_vid', index=4,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='i_pbits', full_name='openolt.Action.i_pbits', index=5,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='i_tpid', full_name='openolt.Action.i_tpid', index=6,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4921,
  serialized_end=5058,
)


_FLOW_PBITTOGEMPORTENTRY = _descriptor.Descriptor(
  name='PbitToGemportEntry',
  full_name='openolt.Flow.PbitToGemportEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='openolt.Flow.PbitToGemportEntry.key', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='openolt.Flow.PbitToGemportEntry.value', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5502,
  serialized_end=5554,
)

_FLOW = _descriptor.Descriptor(
  name='Flow',
  full_name='openolt.Flow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_intf_id', full_name='openolt.Flow.access_intf_id', index=0,
      number=1, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.Flow.onu_id', index=1,
      number=2, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uni_id', full_name='openolt.Flow.uni_id', index=2,
      number=11, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flow_id', full_name='openolt.Flow.flow_id', index=3,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symmetric_flow_id', full_name='openolt.Flow.symmetric_flow_id', index=4,
      number=18, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flow_type', full_name='openolt.Flow.flow_type', index=5,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alloc_id', full_name='openolt.Flow.alloc_id', index=6,
      number=10, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_intf_id', full_name='openolt.Flow.network_intf_id', index=7,
      number=5, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gemport_id', full_name='openolt.Flow.gemport_id', index=8,
      number=6, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='classifier', full_name='openolt.Flow.classifier', index=9,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='openolt.Flow.action', index=10,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='openolt.Flow.priority', index=11,
      number=9, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cookie', full_name='openolt.Flow.cookie', index=12,
      number=12, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_no', full_name='openolt.Flow.port_no', index=13,
      number=13, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_id', full_name='openolt.Flow.group_id', index=14,
      number=14, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tech_profile_id', full_name='openolt.Flow.tech_profile_id', index=15,
      number=15, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replicate_flow', full_name='openolt.Flow.replicate_flow', index=16,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pbit_to_gemport', full_name='openolt.Flow.pbit_to_gemport', index=17,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FLOW_PBITTOGEMPORTENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5061,
  serialized_end=5554,
)


_SERIALNUMBER = _descriptor.Descriptor(
  name='SerialNumber',
  full_name='openolt.SerialNumber',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor_id', full_name='openolt.SerialNumber.vendor_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vendor_specific', full_name='openolt.SerialNumber.vendor_specific', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5556,
  serialized_end=5614,
)


_PORTSTATISTICS = _descriptor.Descriptor(
  name='PortStatistics',
  full_name='openolt.PortStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.PortStatistics.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_bytes', full_name='openolt.PortStatistics.rx_bytes', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_packets', full_name='openolt.PortStatistics.rx_packets', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_ucast_packets', full_name='openolt.PortStatistics.rx_ucast_packets', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_mcast_packets', full_name='openolt.PortStatistics.rx_mcast_packets', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_bcast_packets', full_name='openolt.PortStatistics.rx_bcast_packets', index=5,
      number=6, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_error_packets', full_name='openolt.PortStatistics.rx_error_packets', index=6,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_bytes', full_name='openolt.PortStatistics.tx_bytes', index=7,
      number=8, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_packets', full_name='openolt.PortStatistics.tx_packets', index=8,
      number=9, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_ucast_packets', full_name='openolt.PortStatistics.tx_ucast_packets', index=9,
      number=10, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_mcast_packets', full_name='openolt.PortStatistics.tx_mcast_packets', index=10,
      number=11, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_bcast_packets', full_name='openolt.PortStatistics.tx_bcast_packets', index=11,
      number=12, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_error_packets', full_name='openolt.PortStatistics.tx_error_packets', index=12,
      number=13, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_crc_errors', full_name='openolt.PortStatistics.rx_crc_errors', index=13,
      number=14, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bip_errors', full_name='openolt.PortStatistics.bip_errors', index=14,
      number=15, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='openolt.PortStatistics.timestamp', index=15,
      number=16, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5617,
  serialized_end=5996,
)


_FLOWSTATISTICS = _descriptor.Descriptor(
  name='FlowStatistics',
  full_name='openolt.FlowStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flow_id', full_name='openolt.FlowStatistics.flow_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_bytes', full_name='openolt.FlowStatistics.rx_bytes', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_packets', full_name='openolt.FlowStatistics.rx_packets', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_bytes', full_name='openolt.FlowStatistics.tx_bytes', index=3,
      number=8, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_packets', full_name='openolt.FlowStatistics.tx_packets', index=4,
      number=9, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='openolt.FlowStatistics.timestamp', index=5,
      number=16, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5999,
  serialized_end=6127,
)


_LOSINDICATION = _descriptor.Descriptor(
  name='LosIndication',
  full_name='openolt.LosIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.LosIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='openolt.LosIndication.status', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6129,
  serialized_end=6177,
)


_DYINGGASPINDICATION = _descriptor.Descriptor(
  name='DyingGaspIndication',
  full_name='openolt.DyingGaspIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.DyingGaspIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.DyingGaspIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='openolt.DyingGaspIndication.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6179,
  serialized_end=6249,
)


_ONUALARMINDICATION = _descriptor.Descriptor(
  name='OnuAlarmIndication',
  full_name='openolt.OnuAlarmIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuAlarmIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuAlarmIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='los_status', full_name='openolt.OnuAlarmIndication.los_status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lob_status', full_name='openolt.OnuAlarmIndication.lob_status', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lopc_miss_status', full_name='openolt.OnuAlarmIndication.lopc_miss_status', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lopc_mic_error_status', full_name='openolt.OnuAlarmIndication.lopc_mic_error_status', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lofi_status', full_name='openolt.OnuAlarmIndication.lofi_status', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loami_status', full_name='openolt.OnuAlarmIndication.loami_status', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6252,
  serialized_end=6445,
)


_ONUSTARTUPFAILUREINDICATION = _descriptor.Descriptor(
  name='OnuStartupFailureIndication',
  full_name='openolt.OnuStartupFailureIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuStartupFailureIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuStartupFailureIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='openolt.OnuStartupFailureIndication.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6447,
  serialized_end=6525,
)


_ONUSIGNALDEGRADEINDICATION = _descriptor.Descriptor(
  name='OnuSignalDegradeIndication',
  full_name='openolt.OnuSignalDegradeIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuSignalDegradeIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuSignalDegradeIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='openolt.OnuSignalDegradeIndication.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inverse_bit_error_rate', full_name='openolt.OnuSignalDegradeIndication.inverse_bit_error_rate', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6527,
  serialized_end=6636,
)


_ONUDRIFTOFWINDOWINDICATION = _descriptor.Descriptor(
  name='OnuDriftOfWindowIndication',
  full_name='openolt.OnuDriftOfWindowIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuDriftOfWindowIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuDriftOfWindowIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='openolt.OnuDriftOfWindowIndication.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drift', full_name='openolt.OnuDriftOfWindowIndication.drift', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_eqd', full_name='openolt.OnuDriftOfWindowIndication.new_eqd', index=4,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6638,
  serialized_end=6747,
)


_ONULOSSOFOMCICHANNELINDICATION = _descriptor.Descriptor(
  name='OnuLossOfOmciChannelIndication',
  full_name='openolt.OnuLossOfOmciChannelIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuLossOfOmciChannelIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuLossOfOmciChannelIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='openolt.OnuLossOfOmciChannelIndication.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6749,
  serialized_end=6830,
)


_ONUSIGNALSFAILUREINDICATION = _descriptor.Descriptor(
  name='OnuSignalsFailureIndication',
  full_name='openolt.OnuSignalsFailureIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuSignalsFailureIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuSignalsFailureIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='openolt.OnuSignalsFailureIndication.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inverse_bit_error_rate', full_name='openolt.OnuSignalsFailureIndication.inverse_bit_error_rate', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6832,
  serialized_end=6942,
)


_ONUTRANSMISSIONINTERFERENCEWARNING = _descriptor.Descriptor(
  name='OnuTransmissionInterferenceWarning',
  full_name='openolt.OnuTransmissionInterferenceWarning',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuTransmissionInterferenceWarning.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuTransmissionInterferenceWarning.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='openolt.OnuTransmissionInterferenceWarning.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drift', full_name='openolt.OnuTransmissionInterferenceWarning.drift', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6944,
  serialized_end=7044,
)


_ONUACTIVATIONFAILUREINDICATION = _descriptor.Descriptor(
  name='OnuActivationFailureIndication',
  full_name='openolt.OnuActivationFailureIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuActivationFailureIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuActivationFailureIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fail_reason', full_name='openolt.OnuActivationFailureIndication.fail_reason', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7046,
  serialized_end=7132,
)


_ONULOSSOFKEYSYNCFAILUREINDICATION = _descriptor.Descriptor(
  name='OnuLossOfKeySyncFailureIndication',
  full_name='openolt.OnuLossOfKeySyncFailureIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuLossOfKeySyncFailureIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuLossOfKeySyncFailureIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='openolt.OnuLossOfKeySyncFailureIndication.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7134,
  serialized_end=7218,
)


_RDIERRORINDICATION = _descriptor.Descriptor(
  name='RdiErrorIndication',
  full_name='openolt.RdiErrorIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rdi_error_count', full_name='openolt.RdiErrorIndication.rdi_error_count', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='openolt.RdiErrorIndication.status', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7220,
  serialized_end=7281,
)


_ONUITUPONSTATSINDICATION = _descriptor.Descriptor(
  name='OnuItuPonStatsIndication',
  full_name='openolt.OnuItuPonStatsIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuItuPonStatsIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuItuPonStatsIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rdi_error_ind', full_name='openolt.OnuItuPonStatsIndication.rdi_error_ind', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='stats', full_name='openolt.OnuItuPonStatsIndication.stats',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=7283,
  serialized_end=7405,
)


_ONUPROCESSINGERRORINDICATION = _descriptor.Descriptor(
  name='OnuProcessingErrorIndication',
  full_name='openolt.OnuProcessingErrorIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuProcessingErrorIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuProcessingErrorIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7407,
  serialized_end=7470,
)


_ONUDEACTIVATIONFAILUREINDICATION = _descriptor.Descriptor(
  name='OnuDeactivationFailureIndication',
  full_name='openolt.OnuDeactivationFailureIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuDeactivationFailureIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuDeactivationFailureIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='openolt.OnuDeactivationFailureIndication.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7472,
  serialized_end=7555,
)


_ONUREMOTEDEFECTINDICATION = _descriptor.Descriptor(
  name='OnuRemoteDefectIndication',
  full_name='openolt.OnuRemoteDefectIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuRemoteDefectIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuRemoteDefectIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rdi_errors', full_name='openolt.OnuRemoteDefectIndication.rdi_errors', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7557,
  serialized_end=7637,
)


_ONULOSSOFGEMCHANNELDELINEATIONINDICATION = _descriptor.Descriptor(
  name='OnuLossOfGEMChannelDelineationIndication',
  full_name='openolt.OnuLossOfGEMChannelDelineationIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuLossOfGEMChannelDelineationIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuLossOfGEMChannelDelineationIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='openolt.OnuLossOfGEMChannelDelineationIndication.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delineation_errors', full_name='openolt.OnuLossOfGEMChannelDelineationIndication.delineation_errors', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7639,
  serialized_end=7758,
)


_ONUPHYSICALEQUIPMENTERRORINDICATION = _descriptor.Descriptor(
  name='OnuPhysicalEquipmentErrorIndication',
  full_name='openolt.OnuPhysicalEquipmentErrorIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuPhysicalEquipmentErrorIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuPhysicalEquipmentErrorIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='openolt.OnuPhysicalEquipmentErrorIndication.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7760,
  serialized_end=7846,
)


_ONULOSSOFACKNOWLEDGEMENTINDICATION = _descriptor.Descriptor(
  name='OnuLossOfAcknowledgementIndication',
  full_name='openolt.OnuLossOfAcknowledgementIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuLossOfAcknowledgementIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuLossOfAcknowledgementIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='openolt.OnuLossOfAcknowledgementIndication.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7848,
  serialized_end=7933,
)


_ONUDIFFERENTIALREACHEXCEEDEDINDICATION = _descriptor.Descriptor(
  name='OnuDifferentialReachExceededIndication',
  full_name='openolt.OnuDifferentialReachExceededIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuDifferentialReachExceededIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuDifferentialReachExceededIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='openolt.OnuDifferentialReachExceededIndication.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance', full_name='openolt.OnuDifferentialReachExceededIndication.distance', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7935,
  serialized_end=8042,
)


_GROUPMEMBER = _descriptor.Descriptor(
  name='GroupMember',
  full_name='openolt.GroupMember',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='openolt.GroupMember.interface_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interface_type', full_name='openolt.GroupMember.interface_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gem_port_id', full_name='openolt.GroupMember.gem_port_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='openolt.GroupMember.priority', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GROUPMEMBER_INTERFACETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8045,
  serialized_end=8242,
)


_GROUP = _descriptor.Descriptor(
  name='Group',
  full_name='openolt.Group',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='openolt.Group.group_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command', full_name='openolt.Group.command', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='members', full_name='openolt.Group.members', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='openolt.Group.action', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GROUP_GROUPMEMBERSCOMMAND,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8245,
  serialized_end=8472,
)


_VALUEPARAM = _descriptor.Descriptor(
  name='ValueParam',
  full_name='openolt.ValueParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='onu', full_name='openolt.ValueParam.onu', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='openolt.ValueParam.value', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8474,
  serialized_end=8552,
)


_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='openolt.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8554,
  serialized_end=8561,
)

_INDICATION.fields_by_name['olt_ind'].message_type = _OLTINDICATION
_INDICATION.fields_by_name['intf_ind'].message_type = _INTFINDICATION
_INDICATION.fields_by_name['intf_oper_ind'].message_type = _INTFOPERINDICATION
_INDICATION.fields_by_name['onu_disc_ind'].message_type = _ONUDISCINDICATION
_INDICATION.fields_by_name['onu_ind'].message_type = _ONUINDICATION
_INDICATION.fields_by_name['omci_ind'].message_type = _OMCIINDICATION
_INDICATION.fields_by_name['pkt_ind'].message_type = _PACKETINDICATION
_INDICATION.fields_by_name['port_stats'].message_type = _PORTSTATISTICS
_INDICATION.fields_by_name['flow_stats'].message_type = _FLOWSTATISTICS
_INDICATION.fields_by_name['alarm_ind'].message_type = _ALARMINDICATION
_INDICATION.oneofs_by_name['data'].fields.append(
  _INDICATION.fields_by_name['olt_ind'])
_INDICATION.fields_by_name['olt_ind'].containing_oneof = _INDICATION.oneofs_by_name['data']
_INDICATION.oneofs_by_name['data'].fields.append(
  _INDICATION.fields_by_name['intf_ind'])
_INDICATION.fields_by_name['intf_ind'].containing_oneof = _INDICATION.oneofs_by_name['data']
_INDICATION.oneofs_by_name['data'].fields.append(
  _INDICATION.fields_by_name['intf_oper_ind'])
_INDICATION.fields_by_name['intf_oper_ind'].containing_oneof = _INDICATION.oneofs_by_name['data']
_INDICATION.oneofs_by_name['data'].fields.append(
  _INDICATION.fields_by_name['onu_disc_ind'])
_INDICATION.fields_by_name['onu_disc_ind'].containing_oneof = _INDICATION.oneofs_by_name['data']
_INDICATION.oneofs_by_name['data'].fields.append(
  _INDICATION.fields_by_name['onu_ind'])
_INDICATION.fields_by_name['onu_ind'].containing_oneof = _INDICATION.oneofs_by_name['data']
_INDICATION.oneofs_by_name['data'].fields.append(
  _INDICATION.fields_by_name['omci_ind'])
_INDICATION.fields_by_name['omci_ind'].containing_oneof = _INDICATION.oneofs_by_name['data']
_INDICATION.oneofs_by_name['data'].fields.append(
  _INDICATION.fields_by_name['pkt_ind'])
_INDICATION.fields_by_name['pkt_ind'].containing_oneof = _INDICATION.oneofs_by_name['data']
_INDICATION.oneofs_by_name['data'].fields.append(
  _INDICATION.fields_by_name['port_stats'])
_INDICATION.fields_by_name['port_stats'].containing_oneof = _INDICATION.oneofs_by_name['data']
_INDICATION.oneofs_by_name['data'].fields.append(
  _INDICATION.fields_by_name['flow_stats'])
_INDICATION.fields_by_name['flow_stats'].containing_oneof = _INDICATION.oneofs_by_name['data']
_INDICATION.oneofs_by_name['data'].fields.append(
  _INDICATION.fields_by_name['alarm_ind'])
_INDICATION.fields_by_name['alarm_ind'].containing_oneof = _INDICATION.oneofs_by_name['data']
_ALARMINDICATION.fields_by_name['los_ind'].message_type = _LOSINDICATION
_ALARMINDICATION.fields_by_name['dying_gasp_ind'].message_type = _DYINGGASPINDICATION
_ALARMINDICATION.fields_by_name['onu_alarm_ind'].message_type = _ONUALARMINDICATION
_ALARMINDICATION.fields_by_name['onu_startup_fail_ind'].message_type = _ONUSTARTUPFAILUREINDICATION
_ALARMINDICATION.fields_by_name['onu_signal_degrade_ind'].message_type = _ONUSIGNALDEGRADEINDICATION
_ALARMINDICATION.fields_by_name['onu_drift_of_window_ind'].message_type = _ONUDRIFTOFWINDOWINDICATION
_ALARMINDICATION.fields_by_name['onu_loss_omci_ind'].message_type = _ONULOSSOFOMCICHANNELINDICATION
_ALARMINDICATION.fields_by_name['onu_signals_fail_ind'].message_type = _ONUSIGNALSFAILUREINDICATION
_ALARMINDICATION.fields_by_name['onu_tiwi_ind'].message_type = _ONUTRANSMISSIONINTERFERENCEWARNING
_ALARMINDICATION.fields_by_name['onu_activation_fail_ind'].message_type = _ONUACTIVATIONFAILUREINDICATION
_ALARMINDICATION.fields_by_name['onu_processing_error_ind'].message_type = _ONUPROCESSINGERRORINDICATION
_ALARMINDICATION.fields_by_name['onu_loss_of_sync_fail_ind'].message_type = _ONULOSSOFKEYSYNCFAILUREINDICATION
_ALARMINDICATION.fields_by_name['onu_itu_pon_stats_ind'].message_type = _ONUITUPONSTATSINDICATION
_ALARMINDICATION.fields_by_name['onu_deactivation_failure_ind'].message_type = _ONUDEACTIVATIONFAILUREINDICATION
_ALARMINDICATION.fields_by_name['onu_remote_defect_ind'].message_type = _ONUREMOTEDEFECTINDICATION
_ALARMINDICATION.fields_by_name['onu_loss_gem_delineation_ind'].message_type = _ONULOSSOFGEMCHANNELDELINEATIONINDICATION
_ALARMINDICATION.fields_by_name['onu_physical_equipment_error_ind'].message_type = _ONUPHYSICALEQUIPMENTERRORINDICATION
_ALARMINDICATION.fields_by_name['onu_loss_of_ack_ind'].message_type = _ONULOSSOFACKNOWLEDGEMENTINDICATION
_ALARMINDICATION.fields_by_name['onu_diff_reach_exceeded_ind'].message_type = _ONUDIFFERENTIALREACHEXCEEDEDINDICATION
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['los_ind'])
_ALARMINDICATION.fields_by_name['los_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['dying_gasp_ind'])
_ALARMINDICATION.fields_by_name['dying_gasp_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_alarm_ind'])
_ALARMINDICATION.fields_by_name['onu_alarm_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_startup_fail_ind'])
_ALARMINDICATION.fields_by_name['onu_startup_fail_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_signal_degrade_ind'])
_ALARMINDICATION.fields_by_name['onu_signal_degrade_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_drift_of_window_ind'])
_ALARMINDICATION.fields_by_name['onu_drift_of_window_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_loss_omci_ind'])
_ALARMINDICATION.fields_by_name['onu_loss_omci_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_signals_fail_ind'])
_ALARMINDICATION.fields_by_name['onu_signals_fail_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_tiwi_ind'])
_ALARMINDICATION.fields_by_name['onu_tiwi_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_activation_fail_ind'])
_ALARMINDICATION.fields_by_name['onu_activation_fail_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_processing_error_ind'])
_ALARMINDICATION.fields_by_name['onu_processing_error_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_loss_of_sync_fail_ind'])
_ALARMINDICATION.fields_by_name['onu_loss_of_sync_fail_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_itu_pon_stats_ind'])
_ALARMINDICATION.fields_by_name['onu_itu_pon_stats_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_deactivation_failure_ind'])
_ALARMINDICATION.fields_by_name['onu_deactivation_failure_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_remote_defect_ind'])
_ALARMINDICATION.fields_by_name['onu_remote_defect_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_loss_gem_delineation_ind'])
_ALARMINDICATION.fields_by_name['onu_loss_gem_delineation_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_physical_equipment_error_ind'])
_ALARMINDICATION.fields_by_name['onu_physical_equipment_error_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_loss_of_ack_ind'])
_ALARMINDICATION.fields_by_name['onu_loss_of_ack_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_diff_reach_exceeded_ind'])
_ALARMINDICATION.fields_by_name['onu_diff_reach_exceeded_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ONUDISCINDICATION.fields_by_name['serial_number'].message_type = _SERIALNUMBER
_ONUINDICATION.fields_by_name['serial_number'].message_type = _SERIALNUMBER
_ONUINDICATION.fields_by_name['fail_reason'].enum_type = _ONUINDICATION_ACTIVATIONFAILREASON
_ONUINDICATION_ACTIVATIONFAILREASON.containing_type = _ONUINDICATION
_ONU.fields_by_name['serial_number'].message_type = _SERIALNUMBER
_DEVICEINFO_DEVICERESOURCERANGES_POOL.fields_by_name['type'].enum_type = _DEVICEINFO_DEVICERESOURCERANGES_POOL_POOLTYPE
_DEVICEINFO_DEVICERESOURCERANGES_POOL.fields_by_name['sharing'].enum_type = _DEVICEINFO_DEVICERESOURCERANGES_POOL_SHARINGTYPE
_DEVICEINFO_DEVICERESOURCERANGES_POOL.containing_type = _DEVICEINFO_DEVICERESOURCERANGES
_DEVICEINFO_DEVICERESOURCERANGES_POOL_POOLTYPE.containing_type = _DEVICEINFO_DEVICERESOURCERANGES_POOL
_DEVICEINFO_DEVICERESOURCERANGES_POOL_SHARINGTYPE.containing_type = _DEVICEINFO_DEVICERESOURCERANGES_POOL
_DEVICEINFO_DEVICERESOURCERANGES.fields_by_name['pools'].message_type = _DEVICEINFO_DEVICERESOURCERANGES_POOL
_DEVICEINFO_DEVICERESOURCERANGES.containing_type = _DEVICEINFO
_DEVICEINFO.fields_by_name['ranges'].message_type = _DEVICEINFO_DEVICERESOURCERANGES
_ACTION.fields_by_name['cmd'].message_type = _ACTIONCMD
_FLOW_PBITTOGEMPORTENTRY.containing_type = _FLOW
_FLOW.fields_by_name['classifier'].message_type = _CLASSIFIER
_FLOW.fields_by_name['action'].message_type = _ACTION
_FLOW.fields_by_name['pbit_to_gemport'].message_type = _FLOW_PBITTOGEMPORTENTRY
_ONUITUPONSTATSINDICATION.fields_by_name['rdi_error_ind'].message_type = _RDIERRORINDICATION
_ONUITUPONSTATSINDICATION.oneofs_by_name['stats'].fields.append(
  _ONUITUPONSTATSINDICATION.fields_by_name['rdi_error_ind'])
_ONUITUPONSTATSINDICATION.fields_by_name['rdi_error_ind'].containing_oneof = _ONUITUPONSTATSINDICATION.oneofs_by_name['stats']
_GROUPMEMBER.fields_by_name['interface_type'].enum_type = _GROUPMEMBER_INTERFACETYPE
_GROUPMEMBER_INTERFACETYPE.containing_type = _GROUPMEMBER
_GROUP.fields_by_name['command'].enum_type = _GROUP_GROUPMEMBERSCOMMAND
_GROUP.fields_by_name['members'].message_type = _GROUPMEMBER
_GROUP.fields_by_name['action'].message_type = _ACTION
_GROUP_GROUPMEMBERSCOMMAND.containing_type = _GROUP
_VALUEPARAM.fields_by_name['onu'].message_type = _ONU
_VALUEPARAM.fields_by_name['value'].enum_type = voltha__protos_dot_common__pb2._VALUETYPE_TYPE
DESCRIPTOR.message_types_by_name['Indication'] = _INDICATION
DESCRIPTOR.message_types_by_name['AlarmIndication'] = _ALARMINDICATION
DESCRIPTOR.message_types_by_name['OltIndication'] = _OLTINDICATION
DESCRIPTOR.message_types_by_name['IntfIndication'] = _INTFINDICATION
DESCRIPTOR.message_types_by_name['OnuDiscIndication'] = _ONUDISCINDICATION
DESCRIPTOR.message_types_by_name['OnuIndication'] = _ONUINDICATION
DESCRIPTOR.message_types_by_name['IntfOperIndication'] = _INTFOPERINDICATION
DESCRIPTOR.message_types_by_name['OmciIndication'] = _OMCIINDICATION
DESCRIPTOR.message_types_by_name['PacketIndication'] = _PACKETINDICATION
DESCRIPTOR.message_types_by_name['Interface'] = _INTERFACE
DESCRIPTOR.message_types_by_name['Heartbeat'] = _HEARTBEAT
DESCRIPTOR.message_types_by_name['Onu'] = _ONU
DESCRIPTOR.message_types_by_name['OnuLogicalDistance'] = _ONULOGICALDISTANCE
DESCRIPTOR.message_types_by_name['OmciMsg'] = _OMCIMSG
DESCRIPTOR.message_types_by_name['OnuPacket'] = _ONUPACKET
DESCRIPTOR.message_types_by_name['UplinkPacket'] = _UPLINKPACKET
DESCRIPTOR.message_types_by_name['DeviceInfo'] = _DEVICEINFO
DESCRIPTOR.message_types_by_name['Classifier'] = _CLASSIFIER
DESCRIPTOR.message_types_by_name['ActionCmd'] = _ACTIONCMD
DESCRIPTOR.message_types_by_name['Action'] = _ACTION
DESCRIPTOR.message_types_by_name['Flow'] = _FLOW
DESCRIPTOR.message_types_by_name['SerialNumber'] = _SERIALNUMBER
DESCRIPTOR.message_types_by_name['PortStatistics'] = _PORTSTATISTICS
DESCRIPTOR.message_types_by_name['FlowStatistics'] = _FLOWSTATISTICS
DESCRIPTOR.message_types_by_name['LosIndication'] = _LOSINDICATION
DESCRIPTOR.message_types_by_name['DyingGaspIndication'] = _DYINGGASPINDICATION
DESCRIPTOR.message_types_by_name['OnuAlarmIndication'] = _ONUALARMINDICATION
DESCRIPTOR.message_types_by_name['OnuStartupFailureIndication'] = _ONUSTARTUPFAILUREINDICATION
DESCRIPTOR.message_types_by_name['OnuSignalDegradeIndication'] = _ONUSIGNALDEGRADEINDICATION
DESCRIPTOR.message_types_by_name['OnuDriftOfWindowIndication'] = _ONUDRIFTOFWINDOWINDICATION
DESCRIPTOR.message_types_by_name['OnuLossOfOmciChannelIndication'] = _ONULOSSOFOMCICHANNELINDICATION
DESCRIPTOR.message_types_by_name['OnuSignalsFailureIndication'] = _ONUSIGNALSFAILUREINDICATION
DESCRIPTOR.message_types_by_name['OnuTransmissionInterferenceWarning'] = _ONUTRANSMISSIONINTERFERENCEWARNING
DESCRIPTOR.message_types_by_name['OnuActivationFailureIndication'] = _ONUACTIVATIONFAILUREINDICATION
DESCRIPTOR.message_types_by_name['OnuLossOfKeySyncFailureIndication'] = _ONULOSSOFKEYSYNCFAILUREINDICATION
DESCRIPTOR.message_types_by_name['RdiErrorIndication'] = _RDIERRORINDICATION
DESCRIPTOR.message_types_by_name['OnuItuPonStatsIndication'] = _ONUITUPONSTATSINDICATION
DESCRIPTOR.message_types_by_name['OnuProcessingErrorIndication'] = _ONUPROCESSINGERRORINDICATION
DESCRIPTOR.message_types_by_name['OnuDeactivationFailureIndication'] = _ONUDEACTIVATIONFAILUREINDICATION
DESCRIPTOR.message_types_by_name['OnuRemoteDefectIndication'] = _ONUREMOTEDEFECTINDICATION
DESCRIPTOR.message_types_by_name['OnuLossOfGEMChannelDelineationIndication'] = _ONULOSSOFGEMCHANNELDELINEATIONINDICATION
DESCRIPTOR.message_types_by_name['OnuPhysicalEquipmentErrorIndication'] = _ONUPHYSICALEQUIPMENTERRORINDICATION
DESCRIPTOR.message_types_by_name['OnuLossOfAcknowledgementIndication'] = _ONULOSSOFACKNOWLEDGEMENTINDICATION
DESCRIPTOR.message_types_by_name['OnuDifferentialReachExceededIndication'] = _ONUDIFFERENTIALREACHEXCEEDEDINDICATION
DESCRIPTOR.message_types_by_name['GroupMember'] = _GROUPMEMBER
DESCRIPTOR.message_types_by_name['Group'] = _GROUP
DESCRIPTOR.message_types_by_name['ValueParam'] = _VALUEPARAM
DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Indication = _reflection.GeneratedProtocolMessageType('Indication', (_message.Message,), {
  'DESCRIPTOR' : _INDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.Indication)
  })
_sym_db.RegisterMessage(Indication)

AlarmIndication = _reflection.GeneratedProtocolMessageType('AlarmIndication', (_message.Message,), {
  'DESCRIPTOR' : _ALARMINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.AlarmIndication)
  })
_sym_db.RegisterMessage(AlarmIndication)

OltIndication = _reflection.GeneratedProtocolMessageType('OltIndication', (_message.Message,), {
  'DESCRIPTOR' : _OLTINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OltIndication)
  })
_sym_db.RegisterMessage(OltIndication)

IntfIndication = _reflection.GeneratedProtocolMessageType('IntfIndication', (_message.Message,), {
  'DESCRIPTOR' : _INTFINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.IntfIndication)
  })
_sym_db.RegisterMessage(IntfIndication)

OnuDiscIndication = _reflection.GeneratedProtocolMessageType('OnuDiscIndication', (_message.Message,), {
  'DESCRIPTOR' : _ONUDISCINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuDiscIndication)
  })
_sym_db.RegisterMessage(OnuDiscIndication)

OnuIndication = _reflection.GeneratedProtocolMessageType('OnuIndication', (_message.Message,), {
  'DESCRIPTOR' : _ONUINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuIndication)
  })
_sym_db.RegisterMessage(OnuIndication)

IntfOperIndication = _reflection.GeneratedProtocolMessageType('IntfOperIndication', (_message.Message,), {
  'DESCRIPTOR' : _INTFOPERINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.IntfOperIndication)
  })
_sym_db.RegisterMessage(IntfOperIndication)

OmciIndication = _reflection.GeneratedProtocolMessageType('OmciIndication', (_message.Message,), {
  'DESCRIPTOR' : _OMCIINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OmciIndication)
  })
_sym_db.RegisterMessage(OmciIndication)

PacketIndication = _reflection.GeneratedProtocolMessageType('PacketIndication', (_message.Message,), {
  'DESCRIPTOR' : _PACKETINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.PacketIndication)
  })
_sym_db.RegisterMessage(PacketIndication)

Interface = _reflection.GeneratedProtocolMessageType('Interface', (_message.Message,), {
  'DESCRIPTOR' : _INTERFACE,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.Interface)
  })
_sym_db.RegisterMessage(Interface)

Heartbeat = _reflection.GeneratedProtocolMessageType('Heartbeat', (_message.Message,), {
  'DESCRIPTOR' : _HEARTBEAT,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.Heartbeat)
  })
_sym_db.RegisterMessage(Heartbeat)

Onu = _reflection.GeneratedProtocolMessageType('Onu', (_message.Message,), {
  'DESCRIPTOR' : _ONU,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.Onu)
  })
_sym_db.RegisterMessage(Onu)

OnuLogicalDistance = _reflection.GeneratedProtocolMessageType('OnuLogicalDistance', (_message.Message,), {
  'DESCRIPTOR' : _ONULOGICALDISTANCE,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuLogicalDistance)
  })
_sym_db.RegisterMessage(OnuLogicalDistance)

OmciMsg = _reflection.GeneratedProtocolMessageType('OmciMsg', (_message.Message,), {
  'DESCRIPTOR' : _OMCIMSG,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OmciMsg)
  })
_sym_db.RegisterMessage(OmciMsg)

OnuPacket = _reflection.GeneratedProtocolMessageType('OnuPacket', (_message.Message,), {
  'DESCRIPTOR' : _ONUPACKET,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuPacket)
  })
_sym_db.RegisterMessage(OnuPacket)

UplinkPacket = _reflection.GeneratedProtocolMessageType('UplinkPacket', (_message.Message,), {
  'DESCRIPTOR' : _UPLINKPACKET,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.UplinkPacket)
  })
_sym_db.RegisterMessage(UplinkPacket)

DeviceInfo = _reflection.GeneratedProtocolMessageType('DeviceInfo', (_message.Message,), {

  'DeviceResourceRanges' : _reflection.GeneratedProtocolMessageType('DeviceResourceRanges', (_message.Message,), {

    'Pool' : _reflection.GeneratedProtocolMessageType('Pool', (_message.Message,), {
      'DESCRIPTOR' : _DEVICEINFO_DEVICERESOURCERANGES_POOL,
      '__module__' : 'voltha_protos.openolt_pb2'
      # @@protoc_insertion_point(class_scope:openolt.DeviceInfo.DeviceResourceRanges.Pool)
      })
    ,
    'DESCRIPTOR' : _DEVICEINFO_DEVICERESOURCERANGES,
    '__module__' : 'voltha_protos.openolt_pb2'
    # @@protoc_insertion_point(class_scope:openolt.DeviceInfo.DeviceResourceRanges)
    })
  ,
  'DESCRIPTOR' : _DEVICEINFO,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.DeviceInfo)
  })
_sym_db.RegisterMessage(DeviceInfo)
_sym_db.RegisterMessage(DeviceInfo.DeviceResourceRanges)
_sym_db.RegisterMessage(DeviceInfo.DeviceResourceRanges.Pool)

Classifier = _reflection.GeneratedProtocolMessageType('Classifier', (_message.Message,), {
  'DESCRIPTOR' : _CLASSIFIER,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.Classifier)
  })
_sym_db.RegisterMessage(Classifier)

ActionCmd = _reflection.GeneratedProtocolMessageType('ActionCmd', (_message.Message,), {
  'DESCRIPTOR' : _ACTIONCMD,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.ActionCmd)
  })
_sym_db.RegisterMessage(ActionCmd)

Action = _reflection.GeneratedProtocolMessageType('Action', (_message.Message,), {
  'DESCRIPTOR' : _ACTION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.Action)
  })
_sym_db.RegisterMessage(Action)

Flow = _reflection.GeneratedProtocolMessageType('Flow', (_message.Message,), {

  'PbitToGemportEntry' : _reflection.GeneratedProtocolMessageType('PbitToGemportEntry', (_message.Message,), {
    'DESCRIPTOR' : _FLOW_PBITTOGEMPORTENTRY,
    '__module__' : 'voltha_protos.openolt_pb2'
    # @@protoc_insertion_point(class_scope:openolt.Flow.PbitToGemportEntry)
    })
  ,
  'DESCRIPTOR' : _FLOW,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.Flow)
  })
_sym_db.RegisterMessage(Flow)
_sym_db.RegisterMessage(Flow.PbitToGemportEntry)

SerialNumber = _reflection.GeneratedProtocolMessageType('SerialNumber', (_message.Message,), {
  'DESCRIPTOR' : _SERIALNUMBER,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.SerialNumber)
  })
_sym_db.RegisterMessage(SerialNumber)

PortStatistics = _reflection.GeneratedProtocolMessageType('PortStatistics', (_message.Message,), {
  'DESCRIPTOR' : _PORTSTATISTICS,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.PortStatistics)
  })
_sym_db.RegisterMessage(PortStatistics)

FlowStatistics = _reflection.GeneratedProtocolMessageType('FlowStatistics', (_message.Message,), {
  'DESCRIPTOR' : _FLOWSTATISTICS,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.FlowStatistics)
  })
_sym_db.RegisterMessage(FlowStatistics)

LosIndication = _reflection.GeneratedProtocolMessageType('LosIndication', (_message.Message,), {
  'DESCRIPTOR' : _LOSINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.LosIndication)
  })
_sym_db.RegisterMessage(LosIndication)

DyingGaspIndication = _reflection.GeneratedProtocolMessageType('DyingGaspIndication', (_message.Message,), {
  'DESCRIPTOR' : _DYINGGASPINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.DyingGaspIndication)
  })
_sym_db.RegisterMessage(DyingGaspIndication)

OnuAlarmIndication = _reflection.GeneratedProtocolMessageType('OnuAlarmIndication', (_message.Message,), {
  'DESCRIPTOR' : _ONUALARMINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuAlarmIndication)
  })
_sym_db.RegisterMessage(OnuAlarmIndication)

OnuStartupFailureIndication = _reflection.GeneratedProtocolMessageType('OnuStartupFailureIndication', (_message.Message,), {
  'DESCRIPTOR' : _ONUSTARTUPFAILUREINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuStartupFailureIndication)
  })
_sym_db.RegisterMessage(OnuStartupFailureIndication)

OnuSignalDegradeIndication = _reflection.GeneratedProtocolMessageType('OnuSignalDegradeIndication', (_message.Message,), {
  'DESCRIPTOR' : _ONUSIGNALDEGRADEINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuSignalDegradeIndication)
  })
_sym_db.RegisterMessage(OnuSignalDegradeIndication)

OnuDriftOfWindowIndication = _reflection.GeneratedProtocolMessageType('OnuDriftOfWindowIndication', (_message.Message,), {
  'DESCRIPTOR' : _ONUDRIFTOFWINDOWINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuDriftOfWindowIndication)
  })
_sym_db.RegisterMessage(OnuDriftOfWindowIndication)

OnuLossOfOmciChannelIndication = _reflection.GeneratedProtocolMessageType('OnuLossOfOmciChannelIndication', (_message.Message,), {
  'DESCRIPTOR' : _ONULOSSOFOMCICHANNELINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuLossOfOmciChannelIndication)
  })
_sym_db.RegisterMessage(OnuLossOfOmciChannelIndication)

OnuSignalsFailureIndication = _reflection.GeneratedProtocolMessageType('OnuSignalsFailureIndication', (_message.Message,), {
  'DESCRIPTOR' : _ONUSIGNALSFAILUREINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuSignalsFailureIndication)
  })
_sym_db.RegisterMessage(OnuSignalsFailureIndication)

OnuTransmissionInterferenceWarning = _reflection.GeneratedProtocolMessageType('OnuTransmissionInterferenceWarning', (_message.Message,), {
  'DESCRIPTOR' : _ONUTRANSMISSIONINTERFERENCEWARNING,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuTransmissionInterferenceWarning)
  })
_sym_db.RegisterMessage(OnuTransmissionInterferenceWarning)

OnuActivationFailureIndication = _reflection.GeneratedProtocolMessageType('OnuActivationFailureIndication', (_message.Message,), {
  'DESCRIPTOR' : _ONUACTIVATIONFAILUREINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuActivationFailureIndication)
  })
_sym_db.RegisterMessage(OnuActivationFailureIndication)

OnuLossOfKeySyncFailureIndication = _reflection.GeneratedProtocolMessageType('OnuLossOfKeySyncFailureIndication', (_message.Message,), {
  'DESCRIPTOR' : _ONULOSSOFKEYSYNCFAILUREINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuLossOfKeySyncFailureIndication)
  })
_sym_db.RegisterMessage(OnuLossOfKeySyncFailureIndication)

RdiErrorIndication = _reflection.GeneratedProtocolMessageType('RdiErrorIndication', (_message.Message,), {
  'DESCRIPTOR' : _RDIERRORINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.RdiErrorIndication)
  })
_sym_db.RegisterMessage(RdiErrorIndication)

OnuItuPonStatsIndication = _reflection.GeneratedProtocolMessageType('OnuItuPonStatsIndication', (_message.Message,), {
  'DESCRIPTOR' : _ONUITUPONSTATSINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuItuPonStatsIndication)
  })
_sym_db.RegisterMessage(OnuItuPonStatsIndication)

OnuProcessingErrorIndication = _reflection.GeneratedProtocolMessageType('OnuProcessingErrorIndication', (_message.Message,), {
  'DESCRIPTOR' : _ONUPROCESSINGERRORINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuProcessingErrorIndication)
  })
_sym_db.RegisterMessage(OnuProcessingErrorIndication)

OnuDeactivationFailureIndication = _reflection.GeneratedProtocolMessageType('OnuDeactivationFailureIndication', (_message.Message,), {
  'DESCRIPTOR' : _ONUDEACTIVATIONFAILUREINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuDeactivationFailureIndication)
  })
_sym_db.RegisterMessage(OnuDeactivationFailureIndication)

OnuRemoteDefectIndication = _reflection.GeneratedProtocolMessageType('OnuRemoteDefectIndication', (_message.Message,), {
  'DESCRIPTOR' : _ONUREMOTEDEFECTINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuRemoteDefectIndication)
  })
_sym_db.RegisterMessage(OnuRemoteDefectIndication)

OnuLossOfGEMChannelDelineationIndication = _reflection.GeneratedProtocolMessageType('OnuLossOfGEMChannelDelineationIndication', (_message.Message,), {
  'DESCRIPTOR' : _ONULOSSOFGEMCHANNELDELINEATIONINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuLossOfGEMChannelDelineationIndication)
  })
_sym_db.RegisterMessage(OnuLossOfGEMChannelDelineationIndication)

OnuPhysicalEquipmentErrorIndication = _reflection.GeneratedProtocolMessageType('OnuPhysicalEquipmentErrorIndication', (_message.Message,), {
  'DESCRIPTOR' : _ONUPHYSICALEQUIPMENTERRORINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuPhysicalEquipmentErrorIndication)
  })
_sym_db.RegisterMessage(OnuPhysicalEquipmentErrorIndication)

OnuLossOfAcknowledgementIndication = _reflection.GeneratedProtocolMessageType('OnuLossOfAcknowledgementIndication', (_message.Message,), {
  'DESCRIPTOR' : _ONULOSSOFACKNOWLEDGEMENTINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuLossOfAcknowledgementIndication)
  })
_sym_db.RegisterMessage(OnuLossOfAcknowledgementIndication)

OnuDifferentialReachExceededIndication = _reflection.GeneratedProtocolMessageType('OnuDifferentialReachExceededIndication', (_message.Message,), {
  'DESCRIPTOR' : _ONUDIFFERENTIALREACHEXCEEDEDINDICATION,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuDifferentialReachExceededIndication)
  })
_sym_db.RegisterMessage(OnuDifferentialReachExceededIndication)

GroupMember = _reflection.GeneratedProtocolMessageType('GroupMember', (_message.Message,), {
  'DESCRIPTOR' : _GROUPMEMBER,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.GroupMember)
  })
_sym_db.RegisterMessage(GroupMember)

Group = _reflection.GeneratedProtocolMessageType('Group', (_message.Message,), {
  'DESCRIPTOR' : _GROUP,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.Group)
  })
_sym_db.RegisterMessage(Group)

ValueParam = _reflection.GeneratedProtocolMessageType('ValueParam', (_message.Message,), {
  'DESCRIPTOR' : _VALUEPARAM,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.ValueParam)
  })
_sym_db.RegisterMessage(ValueParam)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
  'DESCRIPTOR' : _EMPTY,
  '__module__' : 'voltha_protos.openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.Empty)
  })
_sym_db.RegisterMessage(Empty)


DESCRIPTOR._options = None
_FLOW_PBITTOGEMPORTENTRY._options = None

_OPENOLT = _descriptor.ServiceDescriptor(
  name='Openolt',
  full_name='openolt.Openolt',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=8564,
  serialized_end=10866,
  methods=[
  _descriptor.MethodDescriptor(
    name='DisableOlt',
    full_name='openolt.Openolt.DisableOlt',
    index=0,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_EMPTY,
    serialized_options=b'\202\323\344\223\002\020\"\013/v1/Disable:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReenableOlt',
    full_name='openolt.Openolt.ReenableOlt',
    index=1,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_EMPTY,
    serialized_options=b'\202\323\344\223\002\021\"\014/v1/Reenable:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ActivateOnu',
    full_name='openolt.Openolt.ActivateOnu',
    index=2,
    containing_service=None,
    input_type=_ONU,
    output_type=_EMPTY,
    serialized_options=b'\202\323\344\223\002\022\"\r/v1/EnableOnu:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeactivateOnu',
    full_name='openolt.Openolt.DeactivateOnu',
    index=3,
    containing_service=None,
    input_type=_ONU,
    output_type=_EMPTY,
    serialized_options=b'\202\323\344\223\002\023\"\016/v1/DisableOnu:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteOnu',
    full_name='openolt.Openolt.DeleteOnu',
    index=4,
    containing_service=None,
    input_type=_ONU,
    output_type=_EMPTY,
    serialized_options=b'\202\323\344\223\002\022\"\r/v1/DeleteOnu:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OmciMsgOut',
    full_name='openolt.Openolt.OmciMsgOut',
    index=5,
    containing_service=None,
    input_type=_OMCIMSG,
    output_type=_EMPTY,
    serialized_options=b'\202\323\344\223\002\023\"\016/v1/OmciMsgOut:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnuPacketOut',
    full_name='openolt.Openolt.OnuPacketOut',
    index=6,
    containing_service=None,
    input_type=_ONUPACKET,
    output_type=_EMPTY,
    serialized_options=b'\202\323\344\223\002\025\"\020/v1/OnuPacketOut:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UplinkPacketOut',
    full_name='openolt.Openolt.UplinkPacketOut',
    index=7,
    containing_service=None,
    input_type=_UPLINKPACKET,
    output_type=_EMPTY,
    serialized_options=b'\202\323\344\223\002\030\"\023/v1/UplinkPacketOut:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FlowAdd',
    full_name='openolt.Openolt.FlowAdd',
    index=8,
    containing_service=None,
    input_type=_FLOW,
    output_type=_EMPTY,
    serialized_options=b'\202\323\344\223\002\020\"\013/v1/FlowAdd:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FlowRemove',
    full_name='openolt.Openolt.FlowRemove',
    index=9,
    containing_service=None,
    input_type=_FLOW,
    output_type=_EMPTY,
    serialized_options=b'\202\323\344\223\002\023\"\016/v1/FlowRemove:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='HeartbeatCheck',
    full_name='openolt.Openolt.HeartbeatCheck',
    index=10,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_HEARTBEAT,
    serialized_options=b'\202\323\344\223\002\027\"\022/v1/HeartbeatCheck:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EnablePonIf',
    full_name='openolt.Openolt.EnablePonIf',
    index=11,
    containing_service=None,
    input_type=_INTERFACE,
    output_type=_EMPTY,
    serialized_options=b'\202\323\344\223\002\024\"\017/v1/EnablePonIf:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DisablePonIf',
    full_name='openolt.Openolt.DisablePonIf',
    index=12,
    containing_service=None,
    input_type=_INTERFACE,
    output_type=_EMPTY,
    serialized_options=b'\202\323\344\223\002\025\"\020/v1/DisablePonIf:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDeviceInfo',
    full_name='openolt.Openolt.GetDeviceInfo',
    index=13,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_DEVICEINFO,
    serialized_options=b'\202\323\344\223\002\026\"\021/v1/GetDeviceInfo:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Reboot',
    full_name='openolt.Openolt.Reboot',
    index=14,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_EMPTY,
    serialized_options=b'\202\323\344\223\002\017\"\n/v1/Reboot:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CollectStatistics',
    full_name='openolt.Openolt.CollectStatistics',
    index=15,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_EMPTY,
    serialized_options=b'\202\323\344\223\002\032\"\025/v1/CollectStatistics:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateTrafficSchedulers',
    full_name='openolt.Openolt.CreateTrafficSchedulers',
    index=16,
    containing_service=None,
    input_type=voltha__protos_dot_tech__profile__pb2._TRAFFICSCHEDULERS,
    output_type=_EMPTY,
    serialized_options=b'\202\323\344\223\002 \"\033/v1/CreateTrafficSchedulers:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveTrafficSchedulers',
    full_name='openolt.Openolt.RemoveTrafficSchedulers',
    index=17,
    containing_service=None,
    input_type=voltha__protos_dot_tech__profile__pb2._TRAFFICSCHEDULERS,
    output_type=_EMPTY,
    serialized_options=b'\202\323\344\223\002 \"\033/v1/RemoveTrafficSchedulers:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateTrafficQueues',
    full_name='openolt.Openolt.CreateTrafficQueues',
    index=18,
    containing_service=None,
    input_type=voltha__protos_dot_tech__profile__pb2._TRAFFICQUEUES,
    output_type=_EMPTY,
    serialized_options=b'\202\323\344\223\002\034\"\027/v1/CreateTrafficQueues:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveTrafficQueues',
    full_name='openolt.Openolt.RemoveTrafficQueues',
    index=19,
    containing_service=None,
    input_type=voltha__protos_dot_tech__profile__pb2._TRAFFICQUEUES,
    output_type=_EMPTY,
    serialized_options=b'\202\323\344\223\002\034\"\027/v1/RemoveTrafficQueues:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EnableIndication',
    full_name='openolt.Openolt.EnableIndication',
    index=20,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_INDICATION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PerformGroupOperation',
    full_name='openolt.Openolt.PerformGroupOperation',
    index=21,
    containing_service=None,
    input_type=_GROUP,
    output_type=_EMPTY,
    serialized_options=b'\202\323\344\223\002\036\"\031/v1/PerformGroupOperation:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteGroup',
    full_name='openolt.Openolt.DeleteGroup',
    index=22,
    containing_service=None,
    input_type=_GROUP,
    output_type=_EMPTY,
    serialized_options=b'\202\323\344\223\002\024\"\017/v1/DeleteGroup:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetExtValue',
    full_name='openolt.Openolt.GetExtValue',
    index=23,
    containing_service=None,
    input_type=_VALUEPARAM,
    output_type=voltha__protos_dot_common__pb2._RETURNVALUES,
    serialized_options=b'\202\323\344\223\002\024\"\017/v1/GetExtValue:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnuItuPonAlarmSet',
    full_name='openolt.Openolt.OnuItuPonAlarmSet',
    index=24,
    containing_service=None,
    input_type=voltha__protos_dot_ext__config__pb2._ONUITUPONALARM,
    output_type=_EMPTY,
    serialized_options=b'\202\323\344\223\002\032\"\025/v1/OnuItuPonAlarmSet:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLogicalOnuDistanceZero',
    full_name='openolt.Openolt.GetLogicalOnuDistanceZero',
    index=25,
    containing_service=None,
    input_type=_ONU,
    output_type=_ONULOGICALDISTANCE,
    serialized_options=b'\202\323\344\223\002\"\"\035/v1/GetLogicalOnuDistanceZero:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLogicalOnuDistance',
    full_name='openolt.Openolt.GetLogicalOnuDistance',
    index=26,
    containing_service=None,
    input_type=_ONU,
    output_type=_ONULOGICALDISTANCE,
    serialized_options=b'\202\323\344\223\002\036\"\031/v1/GetLogicalOnuDistance:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_OPENOLT)

DESCRIPTOR.services_by_name['Openolt'] = _OPENOLT

# @@protoc_insertion_point(module_scope)
